aboutsummaryrefslogtreecommitdiff
path: root/apps/examples/qencoder/qe.h
diff options
context:
space:
mode:
Diffstat (limited to 'apps/examples/qencoder/qe.h')
-rw-r--r--apps/examples/qencoder/qe.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/apps/examples/qencoder/qe.h b/apps/examples/qencoder/qe.h
index 1571da7b2..4c03689ab 100644
--- a/apps/examples/qencoder/qe.h
+++ b/apps/examples/qencoder/qe.h
@@ -100,9 +100,11 @@
#ifdef CONFIG_NSH_BUILTIN_APPS
struct qe_example_s
{
- bool reset; /* True: set the count back to zero */
- unsigned int nloops; /* Collect this number of samples */
- unsigned int delay; /* Delay this number of seconds between samples */
+ bool initialized; /* True: QE devices have been initialized */
+ bool reset; /* True: set the count back to zero */
+ FAR char *devpath; /* Path to the QE device */
+ unsigned int nloops; /* Collect this number of samples */
+ unsigned int delay; /* Delay this number of seconds between samples */
};
#endif